@@ -42,6 +42,7 @@ from time import monotonic
 import jwt
 from jwt.algorithms import RSAAlgorithm
 from six.moves.urllib_parse import urlencode, urlparse, urlunsplit
+from sqlalchemy import exc
 from tornado import escape
 from tornado.auth import OAuth2Mixin
 from tornado.httpclient import HTTPClientError, HTTPRequest
@@ -52,6 +53,7 @@ from univention.management.console.error import BadRequest, NotFound, OpenIDProv
 from univention.management.console.log import CORE
 from univention.management.console.resource import Resource
 from univention.management.console.session import Session
+from univention.management.console.session_db import DBDisabledException, get_session
 from univention.management.console.shared_memory import shared_memory
 
 
@@ -531,15 +533,17 @@ class OIDCBackchannelLogout(OIDCResource):
             self.finish({'error': 'invalid_request', 'error_description': str(exc)})
             return
 
-        sessions = [user for user in Session.sessions.values() if user and user.oidc and user.oidc.id_token and claims['iss'] == user.oidc.claims['iss']]
-        for user in sessions:
-            if user.oidc.claims['sid'] == claims.get('sid'):
-                user.logout()
-                break
-        else:
-            for user in sessions:
-                if user.oidc.claims['sub'] == claims.get('sub'):
-                    user.logout()
+        for session in Session.sessions.get_oidc_sessions(claims):
+            if session.session_id in Session.sessions.sessions:
+                Session.sessions[session.session_id].logout()
+            else:
+                try:
+                    with get_session() as db_session:
+                        session.delete(db_session, session.session_id, True)
+                except exc.DBAPIError as err:
+                    CORE.error('Deleting the session from the database during OIDC backchannel logout failed\n%s' % (err))
+                except DBDisabledException:
+                    pass
 
         self.finish()
 
